:mod:`langacore.kit.cache.memoization`
======================================

.. automodule:: langacore.kit.cache.memoization

.. note::

  Instead of importing the whole structure, a recommended shortcut is available.
  Use ``from langacore.kit.cache import memoize``.

Functions
----------

.. autofunction:: memoize
